@@ -4,15 +4,18 @@ function(x,i,j,info,value){
 
     lab<- attr(x, "label.SNPs")
     val<- names(out)[!(names(out) %in% lab) & !(names(out) %in% names(x))]
-    inf<- attr(x, "gen.info")
     if(!is.null(val)){ # new var
-       lab<-c(lab,val)
-       if(!is.null(inf)) {
-          if (missing(info)){
-              info<-rep(NA,ncol(inf))
-              warning("info was filled with NA")
+       inf<- attr(x, "gen.info")
+       if(length(val)>1) warning("More than 1 column added. May break consistency of colSNPs", call.=FALSE)
+       if (is.snp(value)){
+          lab<-c(lab,val[1])
+          if(!is.null(inf)) {
+             if (missing(info)){
+                 info<-rep(NA,ncol(inf))
+                 warning("info was filled with NA")
+             }
+             inf<-rbind(inf,info)
           }
-          inf<-rbind(inf,info)
        }
     }
     if (!is.null(dim(out))){
